# geo tasks

List of important geographical hierarchies:
* 010 - United States
* 040 - States
* 050 - Counties
* 140 - Census tracts
* 310 - Metropolitan and micropolitan areas (cities)
* 500 - Congressional district
* 860 - Zip codes

To use the URLs below, run them like this:

```
curl "<my-url-here>" > feature.geojson
```

Or, from Python, use the subprocess submodule:

```
import subprocess, json

proc = subprocess.Popen(["curl",myurl], stdout=subprocess.PIPE)
dat = proc.stdout.read()

with open('feature.geojson','w') as f:
    json.dump(dat, f)

with open('feature_pretty.geojson','w') as f:
    json.dump(dat, f, separators=(',',': '),indent=4)
```

<br />

## workflows with geojson

To get geojson returned, include `?geom=True` at the end of the url.

### get the geojson for a given entity

If we want to pass a particular geoid and get information 
just about that object (no children objects), here is the 
base url to use:

```
https://api.censusreporter.org/1.0/geo/tiger2016/<hierarchy level code>00US<geoid>?geom=True
```

Example: this passes in level 040 (state level), id 55 (Wisconsin):

```
https://api.censusreporter.org/1.0/geo/tiger2016/04000US55?geom=True
```

### get children objects url scheme

If we want to pass a particular geoid and get information
about that object's children (e.g., counties of a given state),
here is the base url to use:

```
https://api.censusreporter.org/1.0/geo/show/tiger2016?geo_ids=<level to return>|<level of geoid>00US<geoid>
```

### get counties in a state

Use the FIPS code of your desired state to filter counties.
Pass that in, along with the hierarchy level for state.

To get all counties in Mississippi (state id 28):

```
https://api.censusreporter.org/1.0/geo/show/tiger2016?geo_ids=050|04000US28
```

where the geoids code is:

```
050|        return counties
040         passing in a state geoid
00US        filler
28          state geoid 28 (Mississippi)
```

### get all census tracts in a county

Passing in a county (level 050) with geoid 04027 (Yuma), 
and asking for census tracts (140):

```
https://api.censusreporter.org/1.0/geo/show/tiger2016?geo_ids=140|05000US04027
```

### get all counties in a metro area

Passing in a metro level (level 310) with geoid 41860 (San Francisco), 
and asking for counties (050):

```
https://api.censusreporter.org/1.0/geo/show/tiger2016?geo_ids=050|31000US41860
```

### get all metro areas in a state

Here we pass level 040 (state), geoid 06 (California),
and ask for metro areas (310):

```
https://api.censusreporter.org/1.0/geo/show/tiger2016?geo_ids=310|04000US06
```

<br />

## workflows without geojson

### get the parents for a given entity

This will return all parent entities of Macon County, Illinois:

```
$ curl "http://api.censusreporter.org/1.0/geo/tiger2016/05000US17115/parents"
```

