import subprocess, json, os


"""
Populate US County Data

This downloads county data for each state into the directory:

    geo/us_county/
"""


def main():
    fipscodes = get_fipscodes()

    for k in fipscodes:
        v = fipscodes[k]
        if(len(k)==2):
            print(k)
            fips_download(k,v)


def get_fipscodes():
    with open('../fips/fips.json','r') as f:
        fipscodes = json.load(f)
    return fipscodes


def fips_download(abbrev,fips):
    """
    Given a state abbreviation and fips code,
    download to maps/us_county/abbrev_counties.geojson
    """
    prefix = 'maps/us_counties'

    # Just in case
    if(os.path.exists(prefix) is False):
        error = ["Uh oh, did you check out the data/maps submodule?",
                 "Try running 'git submodule update --remote'"]
        raise Exception("\n".join(error))
        
    print("Processing GeoJSON for state %s..."%(abbrev.upper()))

    jf = "%s/%s_counties.geojson"%(prefix,abbrev.lower())
    pjf = "%s/%s_counties_pretty.geojson"%(prefix,abbrev.lower())

    # Assemble state county url
    myurl = "https://api.censusreporter.org/1.0/geo/show/tiger2016?geo_ids=050|04000US%s"%(fips)
    
    proc = subprocess.Popen(["curl",myurl], stdout=subprocess.PIPE)
    dat = json.loads(proc.stdout.read().decode('utf-8'))

    with open(jf,"w") as f:
        json.dump(dat, f)

    with open(pjf,"w") as f:
        json.dump(dat, f, separators=(',',': '),indent=4)

    print("  > Wrote GeoJSON data to: %s, %s"%(jf,pjf))
    print("")


if __name__=="__main__":
    main()

